package javax.swing;

import java.util.Vector;
import java.io.Serializable;

public class DefaultComboBoxModel<E> extends AbstractListModel<E> implements MutableComboBoxModel<E>, Serializable
{
    Vector<E> objects;
    Object selectedObject;
    
    public DefaultComboBoxModel() {
        this.objects = new Vector();
    }
    
    public DefaultComboBoxModel(E[] array) {
        this.objects = new Vector(array.length);
        for (int i = 0; i < array.length; ++i) {
            this.objects.addElement(array[i]);
        }
        if (this.getSize() > 0) {
            this.selectedObject = this.getElementAt(0);
        }
    }
    
    public DefaultComboBoxModel(Vector<E> objects) {
        this.objects = objects;
        if (this.getSize() > 0) {
            this.selectedObject = this.getElementAt(0);
        }
    }
    
    @Override
    public void setSelectedItem(Object o) {
        if ((this.selectedObject != null && !this.selectedObject.equals(o)) || (this.selectedObject == null && o != null)) {
            this.selectedObject = o;
            this.fireContentsChanged(this, -1, -1);
        }
    }
    
    @Override
    public Object getSelectedItem() {
        return this.selectedObject;
    }
    
    @Override
    public int getSize() {
        return this.objects.size();
    }
    
    @Override
    public E getElementAt(int index) {
        if (index >= 0 && index < this.objects.size()) {
            return this.objects.elementAt(index);
        }
        return null;
    }
    
    public int getIndexOf(Object o) {
        return this.objects.indexOf(o);
    }
    
    @Override
    public void addElement(E e) {
        this.objects.addElement(e);
        this.fireIntervalAdded(this, this.objects.size() - 1, this.objects.size() - 1);
        if (this.objects.size() == 1 && this.selectedObject == null && e != null) {
            this.setSelectedItem(e);
        }
    }
    
    @Override
    public void insertElementAt(E obj, int index) {
        this.objects.insertElementAt(obj, index);
        this.fireIntervalAdded(this, index, index);
    }
    
    @Override
    public void removeElementAt(int index) {
        if (this.getElementAt(index) == this.selectedObject) {
            if (index == 0) {
                this.setSelectedItem((this.getSize() == 1) ? null : this.getElementAt(index + 1));
            }
            else {
                this.setSelectedItem(this.getElementAt(index - 1));
            }
        }
        this.objects.removeElementAt(index);
        this.fireIntervalRemoved(this, index, index);
    }
    
    @Override
    public void removeElement(Object o) {
        int index = this.objects.indexOf(o);
        if (index != -1) {
            this.removeElementAt(index);
        }
    }
    
    public void removeAllElements() {
        if (this.objects.size() > 0) {
            int n = 0;
            int n2 = this.objects.size() - 1;
            this.objects.removeAllElements();
            this.selectedObject = null;
            this.fireIntervalRemoved(this, n, n2);
        }
        else {
            this.selectedObject = null;
        }
    }
}
